testCens: Sample Test Data for the Iterative BMA Algorithm for Survival Analysis
Description
This is an diffuse large B-cell lymphoma (DLBCL) dataset from Rosenwald et al. (2002).
This is a vector of censor information for 36 test samples. In this vector,
0 = censored and 1 = uncensored.
Format
The vector is called testCens.References
Rosenwald, A., Wright, G., Wing, C., Connors, J., Campo, E. et al. (2002).
The Use of Molecular Profiling to Predict Survival After Chemotherapy for Diffuse Large-B-Cell Lymphoma.
The New England Journal of Medicine, 346(25), 1937-1947.